@@ -7,8 +7,8 @@ if False:  # MYPY
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 15, 43),
-    __version__='0.15.43',
+    version_info=(0, 15, 44),
+    __version__='0.15.44',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
@@ -33,8 +33,9 @@ _package_data = dict(
               /* prevent warning */
               return 0;
             }
-            """,  # NOQA
+            """,
         )],
+                  # NOQA
             # test='#include "ext/yaml.h"\n\nint main(int argc, char* argv[])\n{\nyaml_parser_t parser;\nparser = parser;  /* prevent warning */\nreturn 0;\n}\n',  # NOQA
     classifiers=[
             'Programming Language :: Python :: 2.7',
@@ -54,7 +55,9 @@ _package_data = dict(
     many_linux='libyaml-devel',
     supported=[(2, 7), (3, 4)],  # minimum
     tox=dict(
-        flake8=dict(version='==2.5.5'),
+        flake8=dict(
+            version='==2.5.5',
+        ),
         env='*pn',   # also test narrow 2.7.15
         deps='ruamel.std.pathlib',
         fl8excl='_test/lib',
