@@ -19,13 +19,14 @@ from ruamel.yaml.compat import (utf8, builtins_module, to_str, PY2, PY3,  # NOQA
                                 ordereddict, text_type, nprint, version_tnf)
 from ruamel.yaml.comments import *                               # NOQA
 from ruamel.yaml.comments import (CommentedMap, CommentedOrderedMap, CommentedSet,
-                                  CommentedKeySeq, CommentedSeq)
+                                  CommentedKeySeq, CommentedSeq, TaggedScalar)
 from ruamel.yaml.scalarstring import *                           # NOQA
 from ruamel.yaml.scalarstring import (PreservedScalarString, SingleQuotedScalarString,
                                       DoubleQuotedScalarString, ScalarString)
 from ruamel.yaml.scalarint import ScalarInt, BinaryInt, OctalInt, HexInt, HexCapsInt
 from ruamel.yaml.scalarfloat import ScalarFloat
 from ruamel.yaml.timestamp import TimeStamp
+from ruamel.yaml.util import RegExp
 
 if False:  # MYPY
     from typing import Any, Dict, List, Set, Generator  # NOQA
@@ -254,7 +255,7 @@ class BaseConstructor(object):
                         http://yaml.readthedocs.io/en/latest/api.html#duplicate-keys
                     """,
                     """\
-                    Duplicate keys will become and error in future releases, and are errors
+                    Duplicate keys will become an error in future releases, and are errors
                     by default when using the new API.
                     """,
                 ]
@@ -471,7 +472,7 @@ class SafeConstructor(BaseConstructor):
                     None, None,
                     "failed to decode base64 data: %s" % exc, node.start_mark)
 
-    timestamp_regexp = re.compile(
+    timestamp_regexp = RegExp(
         u'''^(?P<year>[0-9][0-9][0-9][0-9])
           -(?P<month>[0-9][0-9]?)
           -(?P<day>[0-9][0-9]?)
@@ -486,7 +487,15 @@ class SafeConstructor(BaseConstructor):
     def construct_yaml_timestamp(self, node, values=None):
         # type: (Any, Any) -> Any
         if values is None:
-            match = self.timestamp_regexp.match(node.value)
+            try:
+                match = self.timestamp_regexp.match(node.value)
+            except TypeError:
+                match = None
+            if match is None:
+                raise ConstructorError(
+                    None, None,
+                    'failed to construct timestamp from "{}"'.format(node.value),
+                    node.start_mark)
             values = match.groupdict()
         year = int(values['year'])
         month = int(values['month'])
@@ -1411,25 +1420,43 @@ class RoundTripConstructor(SafeConstructor):
     def construct_undefined(self, node):
         # type: (Any) -> Any
         try:
-            data = CommentedMap()
-            data._yaml_set_line_col(node.start_mark.line, node.start_mark.column)
-            if node.flow_style is True:
-                data.fa.set_flow_style()
-            elif node.flow_style is False:
-                data.fa.set_block_style()
-            data.yaml_set_tag(node.tag)
-            yield data
-            self.construct_mapping(node, data)
-        except:
-            raise ConstructorError(
-                None, None,
-                "could not determine a constructor for the tag %r" %
-                utf8(node.tag),
-                node.start_mark)
+            if isinstance(node, MappingNode):
+                data = CommentedMap()
+                data._yaml_set_line_col(node.start_mark.line, node.start_mark.column)
+                if node.flow_style is True:
+                    data.fa.set_flow_style()
+                elif node.flow_style is False:
+                    data.fa.set_block_style()
+                data.yaml_set_tag(node.tag)
+                yield data
+                self.construct_mapping(node, data)
+                return
+            elif isinstance(node, ScalarNode):
+                data = TaggedScalar()
+                data.value = self.construct_scalar(node)
+                data.style = node.style
+                data.yaml_set_tag(node.tag)
+                yield data
+                return
+        except:  # NOQA
+            pass
+        raise ConstructorError(
+            None, None,
+            "could not determine a constructor for the tag %r" %
+            utf8(node.tag),
+            node.start_mark)
 
     def construct_yaml_timestamp(self, node, values=None):
         # type: (Any, Any) -> Any
-        match = self.timestamp_regexp.match(node.value)
+        try:
+            match = self.timestamp_regexp.match(node.value)
+        except TypeError:
+            match = None
+        if match is None:
+            raise ConstructorError(
+                None, None,
+                'failed to construct timestamp from "{}"'.format(node.value),
+                node.start_mark)
         values = match.groupdict()
         if not values['hour']:
             return SafeConstructor.construct_yaml_timestamp(self, node, values)
